/* ==============================================================[ ap-lirc.c ]=
 * Control AlsaPlayer through LIRC.
 * Copyright (C) 2002 Hubert Chan <hubert@uhoreg.ca>
 *
 * ----------------------------------------------------------------( License )-
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * -------------------------------------------------------------( Description)-
 *
 * This program allows one to control AlsaPlayer using a remote control through
 * LIRC (Linux Infrared Remote Control).
 *
 * Lots of code ripped from irexec.c.  Commands based on lirc-xmms-plugin.
 *
 * ------------------------------------------------------------------------- */

#include <string.h>
#include <ctype.h>
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>

#include <alsaplayer/control.h>
#include <lirc/lirc_client.h>

int main(int argc, char *argv[])
{
  struct lirc_config *config;

  char *progname=argv[0];
  if(argc>2)
  {
    fprintf(stderr,"Usage: %s <config file>\n",progname);
    exit(1);
  }

#ifdef DEBUG
  printf("Alsa Player version %d (whatever that means)\n", ap_version());
#endif

  if (!ap_session_running(0))
  { /* if AlsaPlayer is not already running, start it */
#ifdef DEBUG
    printf("Warning: AlsaPlayer not running -- forking\n");
#endif
    if (system("alsaplayer&") < 0)
    {
      fprintf(stderr,"Error: could not start alsaplayer\n");
      exit(1);
    }
  }

  if(lirc_init("alsaplayer",1)==-1) exit(1);

  if(lirc_readconfig(argc==2 ? argv[1]:NULL,&config,NULL)==0)
  {
    char *code;
    char *c;
    int ret;

    while(lirc_nextcode(&code)==0)
    {
      if (!ap_session_running(0))
      {
	fprintf(stderr,"Error: AlsaPlayer died\n");
	exit(1);
      }

      if(code==NULL) continue;
      while((ret=lirc_code2char(config,code,&c))==0 &&
	    c!=NULL)
      {
	int i;
	for (i = 0; c[i] != '\0'; i++)
	  c[i] = tolower(c[i]);
#ifdef DEBUG
	printf("command: %s\n", c);
#endif

	/* big, huge, if-else !!! (okay, not *that* huge) */
	if (strcmp(c, "play") == 0)
	  ap_play(0);
	else if (strcmp(c, "stop") == 0)
	  ap_stop(0);
	else if (strcmp(c, "pause") == 0)
	  ap_pause(0);
	else if (strcmp(c, "playpause") == 0)
	{ /* unpause if it was already paused, pause otherwise */
	  float speed;
	  ap_get_speed(0,&speed);
	  if (speed == 0.0)
	    ap_unpause(0);
	  else
	    ap_pause(0);
	}
	else if (strcmp(c, "next") == 0)
	  ap_next(0);
	else if (strcmp(c, "prev") == 0)
	  ap_prev(0);
	else if (strcmp(c, "quit") == 0)
	{
	  ap_quit(0);
	  free(code);
	  lirc_freeconfig(config);
	  lirc_deinit();
	  exit(0);
	}
      }

      free(code);
      if(ret==-1) break;
    }
    lirc_freeconfig(config);
  }

  lirc_deinit();
  return 0;
}

/* end of ap-lirc.c */
